==> curves_0.8.7.tar.gz: curves-0.8.7/porting.h <==
/* porting.h
   $Id: porting.h,v 1.3 1998/09/07 00:49:36 elf Exp $
   
   written by Marc Singer
   19 Jun 1998

   This file is part of the project CurVeS.  See the file README for
   more information.

   Copyright (C) 1996 Marc Singer

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   in a file called COPYING along with this program; if not, write to
   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
   02139, USA.

*/

#if !defined (__PORTING_H__)
#    define   __PORTING_H__

#include <termios.h>		/* cfmakeraw */

#if !defined (HAVE_CFMAKERAW)
int cfmakeraw (struct termios *termios_p);
#endif

#if !defined (HAVE_VSNPRINTF)
# include <stdarg.h>
# if defined __cplusplus
extern "C" {
# endif
int vsnprintf (char *str, size_t n, const char *format, va_list ap);
# if defined __cplusplus
}
# endif
#endif 

#if !defined (HAVE_RINDEX)
# if defined __cplusplus
extern "C" {
# endif
char* rindex (const char *sz, int c);
# if defined __cplusplus
}
# endif
#endif 


#endif  /* __PORTING_H__ */

==> curves_0.8.19.tar.gz: curves-0.8.19/porting.h <==
/* porting.h
   $Id: porting.h,v 1.4 2001/11/27 23:57:36 elf Exp $
   
   written by Marc Singer
   19 Jun 1998

   This file is part of the project CurVeS.  See the file README for
   more information.

   Copyright (C) 1996 Marc Singer

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   with your Debian GNU/Linux system, in
   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
   source package as the file COPYING. If not, write to the Free
   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
   02111-1307, USA.

*/

#if !defined (__PORTING_H__)
#    define   __PORTING_H__

#include <termios.h>		/* cfmakeraw */

#if !defined (HAVE_CFMAKERAW)
int cfmakeraw (struct termios *termios_p);
#endif

#if !defined (HAVE_VSNPRINTF)
# include <stdarg.h>
# if defined __cplusplus
extern "C" {
# endif
int vsnprintf (char *str, size_t n, const char *format, va_list ap);
# if defined __cplusplus
}
# endif
#endif 

#if !defined (HAVE_RINDEX)
# if defined __cplusplus
extern "C" {
# endif
char* rindex (const char *sz, int c);
# if defined __cplusplus
}
# endif
#endif 


#endif  /* __PORTING_H__ */
